Send metrics to the Riemann monitoring system

## Run the tests

A `tox.ini` file is provided to run the tests with different versions of
Python.

To run the tests:

1. Install tox
2. Run `tox` from the root folder of the repository
